@@ -27,7 +27,7 @@ sub description {
 sub execute {
     my($cmd,$opt,$args) = @_;
 
-    my %SHOW = map { $_ => 1 } split /,|\s+/, $opt->{state};
+    my %SHOW = map { $_ => 1 } exists $opt->{state} ? split /,|\s+/, $opt->{state} : ();
     my $audit = gcr_repo();
     gcr_reset();
 
@@ -83,7 +83,7 @@ Git::Code::Review::Command::list - Quick overview of the Audit Directory
 
 =head1 VERSION
 
-version 0.1
+version 0.2
 
 =head1 AUTHOR
 
